@@ -1,7 +1,7 @@
 <?php
 /*
 
- Copyright (c) 2001 - 2006 Ampache.org
+ Copyright (c) 2001 - 2007 Ampache.org
  All rights reserved.
 
  This program is free software; you can redistribute it and/or
@@ -22,10 +22,8 @@
 <?php show_box_top(scrub_out($title)); ?>
 <?php echo $text; ?>
 <br />
-<div class="text-action">
-	<a href="<?php echo $path; ?>"><?php echo _('Continue'); ?></a>
+	<a class="button" href="<?php echo $path; ?>"><?php echo _('Continue'); ?></a>
 <?php if ($cancel) { ?>
-	<a href="<?php echo conf('web_path') . "/" . return_referer(); ?>"><?php echo _('Cancel'); ?></a>
+	<a class="button" href="<?php echo Config::get('web_path') . "/" . return_referer(); ?>"><?php echo _('Cancel'); ?></a>
 <?php } ?>
-</div>
 <?php show_box_bottom(); ?>
